﻿using Microsoft.EntityFrameworkCore;
using Simbir.Market.Market.Models;

namespace Simbir.Market.Market.Data;

public class DataContext : DbContext
{
    public DbSet<Product> Products { get; set; }
    public DbSet<Tag> Tags { get; set; }
    public DataContext() { }

    public DataContext(DbContextOptions<DataContext> options) : base(options) { }

    protected override void OnModelCreating(ModelBuilder modelBuilder)
    {
        modelBuilder.Entity<Product>().ToTable("products").HasKey(i => i.Id);
        modelBuilder.Entity<Product>().Property(i => i.Id).UseIdentityColumn();
        modelBuilder.Entity<Product>().Property(i => i.Name).HasColumnType("varchar(512)");
        modelBuilder.Entity<Product>().Property(i => i.Description).HasColumnType("varchar(2000)");
        modelBuilder.Entity<Product>().HasIndex(i => new { i.Name, i.UserId }).IsUnique().HasFilter("is_deleted = false");

        modelBuilder.Entity<Tag>().ToTable("tags").HasKey(i => i.Id);
        modelBuilder.Entity<Tag>().Property(i => i.Id).UseIdentityColumn();
        modelBuilder.Entity<Tag>().Property(i => i.Name).HasColumnType("varchar(256)");
        modelBuilder.Entity<Tag>().HasOne<Product>().WithMany().HasForeignKey(r => r.ProductId);
        modelBuilder.Entity<Tag>().HasIndex(i => new { i.Name, i.ProductId }).IsUnique();
    }
}
