using AutoMapper;
using Domain;
using MassTransit;
using Microsoft.AspNetCore.Mvc;
using Simbir.Market.Payment.Controllers.DTO;
using Simbir.Market.Payment.Models;
using Simbir.Market.Payment.Services;
using System.ComponentModel.DataAnnotations;

namespace Simbir.Market.Payment.Controllers
{
    [Route("api/[controller]")]
    [ApiController]
    public class PaymentController : ControllerBase
    {
        //    
        private static readonly Card[] validCards = new[]
        {
            new Card
            {
                CardNumber = "0000 0000 0000 0000",
                Name = "FOMA KINIAEV",
                ExpireDate = "08/69",
                CVV = "007"
            },
            new Card
            {
                CardNumber = "0001 0002 0003 0004",
                Name = "DANILA BAGROV",
                ExpireDate = "12/37",
                CVV = "420"
            }
        };

        private readonly IPaymentService _paymentService;
        private readonly IBus _bus;
        private readonly IMapper _mapper;

        public PaymentController(IPaymentService paymentService, IBus bus, IMapper mapper)
        {
            _paymentService = paymentService;
            _bus = bus;
            _mapper = mapper;
        }

        [HttpPost]
        public async Task<IActionResult> PayAsync([FromBody] CreatePaymentRequest request)
        {
            var response = await _paymentService.CreatePaymentAsync(request);
            return Ok(response);
        }

        [HttpPost("/Pay/{paymentId:int}")]
        public async Task<IActionResult> PayAsync([Required] int paymentId, [FromBody] PayRequest request)
        {
            var isValid = validCards.Any(c => c.CardNumber == request.CardNumber && c.Name == request.Name
                                            && c.ExpireDate == request.ExpireDate && c.CVV == request.CVV);

            if (!isValid)
            {
                return BadRequest("  .");
            }

            await _paymentService.PayAsync(paymentId, request);

            await _bus.Publish(new PaymentMessage
            {
                PaymentId = paymentId
            });

            return Ok();
        }
    }
}
