﻿using Microsoft.AspNetCore.Authorization;
using Microsoft.AspNetCore.Mvc;
using Simbir.Market.Purchase.Attributes;
using Simbir.Market.Purchase.Controllers.DTO;
using Simbir.Market.Purchase.Services;
using System.ComponentModel.DataAnnotations;

namespace Simbir.Market.Purchase.Controllers
{
    [Route("api/[controller]")]
    [ApiController]
    public class PurchaseController : ControllerBase
    {
        private readonly IPurchaseService _purchaseService;
        public PurchaseController(IPurchaseService purchaseService)
        {
            _purchaseService = purchaseService;
        }

        [HttpPost]
        [ApiAuthorize]
        public async Task<IActionResult> CreatePurchaseAsync([FromBody] PurchaseCreateRequest request)
        {
            if (!ModelState.IsValid)
            {
                return BadRequest(ModelState);
            }

            var accessTokenHeader = HttpContext.Request.Headers["Authorization"].ToString();
            var accessToken = accessTokenHeader.Replace("Bearer ", "");

            var paymentId = await _purchaseService.CreatePurchaseAsync(request, accessToken);

            return Ok(paymentId);
        }

        [HttpPost("{id:long}")]
        [ApiAuthorize("Admin,User")]
        public async Task<IActionResult> CancelPurchaseAsync([Required] long id)
        {
            var accessTokenHeader = HttpContext.Request.Headers["Authorization"].ToString();
            var accessToken = accessTokenHeader.Replace("Bearer ", "");

            await _purchaseService.CancelPurchaseAsync(id, accessToken);

            return Ok();
        }

        [HttpGet("{id:long}")]
        [ApiAuthorize("Admin,User")]
        public async Task<IActionResult> GetPurchaseAsync([Required] long id)
        {
            var accessTokenHeader = HttpContext.Request.Headers["Authorization"].ToString();
            var accessToken = accessTokenHeader.Replace("Bearer ", "");

            var status = await _purchaseService.GetPurchaseStatusAsync(id, accessToken);

            return Ok(status);
        }

        [HttpGet("History")]
        [ApiAuthorize("Admin, User")]
        public async Task<IActionResult> GetPurchaseHistoryAsync([FromQuery][Required] long userId, [FromQuery] int from = 0, [FromQuery] int count = 0)
        {
            var accessTokenHeader = HttpContext.Request.Headers["Authorization"].ToString();
            var accessToken = accessTokenHeader.Replace("Bearer ", "");

            var history = await _purchaseService.GetPurchaseHistoryByUserIdAsync(userId, from, count, accessToken);

            return Ok(history);
        }

    }
}
